import 'package:flutter/material.dart';

import 'api/image_service.dart';

class RandomAvatar extends StatefulWidget {
  final double height;
  final double width;
  final Widget loadingPlaceholder;
  final Widget errorPlaceholder;

  const RandomAvatar(
      {super.key,
      required this.height,
      required this.width,
      required this.loadingPlaceholder,
      required this.errorPlaceholder});

  @override
  State<RandomAvatar> createState() => _RandomAvatarState();
}

class _RandomAvatarState extends State<RandomAvatar> {
  bool isLoadingImage = false;
  String? imageFromServer;
  String? state;

  @override
  void initState() {
    getImage();
    super.initState();
  }

  void getImage() async {
    setState(() {
      isLoadingImage = true;
    });

    var response = await ImageService.getRandomImage();

    if (response.statusCode == 200) {
      setState(() {
        imageFromServer = response.body;
        isLoadingImage = false;
        state = "Success";
      });
    } else {
      setState(() {
        imageFromServer = response.body;
        isLoadingImage = false;
        state = "Error";
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        height: widget.height,
        width: widget.width,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(1000),
            color: Colors.accents.first),
        child: isLoadingImage
            ? widget.loadingPlaceholder
            : constructImage(state!, imageFromServer!));
  }

  Widget constructImage(String state, String image) {
    switch (state) {
      case "Success":
        return imageWidget(image);
      case "Error":
        return widget.errorPlaceholder;
      default:
        return widget.errorPlaceholder;
    }
  }

  Widget imageWidget(String image) {
    return Image.network(
      image,
      fit: BoxFit.cover,
    );
  }
}
